@@ -2,6 +2,7 @@
 # coding: utf-8
 # author: Frank YCJ
 # email: 1320259466@qq.com
+import base64
 import hashlib
 
 def get_md5(data,salt="",rounds=1):
@@ -41,4 +42,16 @@ def get_sha512(data):
     sha1.update(data)
     return sha1.hexdigest()
 
+def get_base64_encode(data):
+    return base64.b64encode(data)
 
+
+def get_base64_decode(data):
+    return base64.b64decode(data)
+
+def get_base64_safe_encode(data):
+    return base64.urlsafe_b64encode(data)
+
+
+def get_base64_safe_decode(data):
+    return base64.urlsafe_b64decode(data)
